@@ -5,7 +5,7 @@ from .classes import Column
 from .consts import MIN_OD_VOL
 
 
-__all__ = ['perform_network_assignment']
+__all__ = ['perform_column_generation']
 
 
 def _update_generalized_link_cost(spnetworks):
@@ -318,27 +318,24 @@ def _assignment(spnetworks, column_pool, iter_num):
         _assignment_core(spn, column_pool, iter_num)
 
 
-def perform_network_assignment(assignment_mode, iter_num, column_update_num, ui):
+def perform_column_generation(iter_num, column_update_num, ui):
     """ perform network assignemnt using the selected assignment mode
 
     WARNING
     -------
-        Only Path/Column-based User Equilibrium (UE) is implemented in Python.
-        If you need other assignment modes or dynamic traffic assignment (DTA),
-        please use perform_network_assignment_DTALite()
+    Only Path/Column-based User Equilibrium (UE) is implemented in Python.
+    If you need other assignment modes or dynamic traffic assignment (DTA),
+    please use perform_network_assignment_DTALite()
 
     Parameters
     ----------
-    assignment_mode
-        0: Link-based UE
-        1: Path-based UE
-        2: UE + dynamic traffic assignment and simulation
-        3: ODME
     iter_num
         number of assignment iterations to be performed before optimizing
         column pool
+
     column_update_iter
         number of iterations to be performed on optimizing column pool
+
     ui
         network object generated by pg.read_demand()
 
@@ -351,9 +348,6 @@ def perform_network_assignment(assignment_mode, iter_num, column_update_num, ui)
         assigned volumes and other link attributes on each link (in l
         ink_performance.csv)
     """
-    if assignment_mode != 1:
-        raise Exception("not implemented yet")
-
     # make sure iteration numbers are both non-negative
     assert(iter_num>=0)
     assert(column_update_num>=0)
@@ -414,4 +408,21 @@ def update_links_using_columns(network):
                                                 1,
                                                 False)
 
-    _update_link_travel_time_and_cost(links)
\ No newline at end of file
+    _update_link_travel_time_and_cost(links)
+
+
+def perform_network_assignment(assignment_mode, iter_num, column_update_num, ui):
+    """DEPRECATED Column Generation API
+
+    Keep it here as legacy support for existing users who already get used to it
+    """
+    print('This function has been deprecated, and will be removed later!'
+          'Please use perform_column_generation() instead.')
+
+    if assignment_mode != 1:
+        raise Exception(
+            'NOT implemented yet!'
+            'Please please use perform_network_assignment_DTALite().'
+        )
+
+    perform_column_generation(iter_num, column_update_num, ui)
\ No newline at end of file
